//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.plugin.html.commands;

import java.io.File;
import java.util.List;

import de.ugoe.cs.autoquest.plugin.html.HTMLLogTextInputPseudomizer;
import de.ugoe.cs.util.console.Command;
import de.ugoe.cs.util.console.Console;

/**
 * <p>
 * replaces all text inputs in a directory structure with MD5 hashes of the text input. If the
 * text input is already hashed, it stays unchanged. For this, the command traverses the directory
 * structure. In each directory it treats the contained files as HTML log files. It parses them,
 * copies all GUI elements and events and replaces the entered text of text input events. The result
 * is a copy of each treated log file. The origins are deleted. The copies are named as the origins.
 * </p>
 * 
 * @author Patrick Harms
 * @version 1.0
 */
public class CMDpseudomizeHTMLTextInputs implements Command {

    /* (non-Javadoc)
     * @see de.ugoe.cs.util.console.Command#run(java.util.List)
     */
    @Override
    public void run(List<Object> parameters) {
        String path;

        try {
            path = (String) parameters.get(0);
        }
        catch (Exception e) {
            throw new IllegalArgumentException("illegal parameters provided: " + e);
        }

        File directory = new File(path);
        if (!directory.isDirectory()) {
            Console.printerrln(path + " is not a directory");
            return;
        }

        pseudomizeTextInputsInDirectory(directory);

    }

    /**
     * <p>
     * convenience method to traverse the directory structure
     * </p>
     * 
     * @param directory the directory to be treated next
     */
    private void pseudomizeTextInputsInDirectory(File directory) {
        if (directory.isDirectory()) {
            File[] children = directory.listFiles();
            
            for (File child : children) {
                pseudomizeTextInputsInDirectory(child);
            }
        }
        else if (directory.isFile()) {
            HTMLLogTextInputPseudomizer pseudomizer = new HTMLLogTextInputPseudomizer();
            pseudomizer.pseudomizeFile(directory);
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see de.ugoe.cs.util.console.Command#help()
     */
    @Override
    public String help() {
        return "pseudomizeHTMLTextInputs <directory>";
    }

}
